docs.rs failed to build smbcloud-cli-0.4.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
smbcloud-cli-0.3.26
Installation
You can install the CLI a few different ways.
With Cargo
Homebrew (MacOS/Linux)
With NPM
With PyPI
Update
To update the CLI, run the same install command again.
Uninstall
# With cargo
# With npm
# With Homebrew
# With pip
Usage
Contributing
To work on the CLI locally:
- Set up your Rust tooling.
- Clone the repo.
- Add the required environment variables to
.env.local. - Run
cargo run.
Credits
This repo draws inspiration from Sugar.
It also borrows ideas from the 12 factor CLI app.
More CLI and deployment guides live in the smbCloud docs.
License
Copyright
© 2026 smbCloud (Splitfire AB).